#include "CGUInit.h"

extern uint32_t SystemCoreClock;

/**************************************************************************************************************************
	Function name	:   CGU_Init
    Description		:   This function initializes the CGU to configure different clocks in system.
	Arguments		:	Parameter			|	Description							|	Valid values
						iMultiplier			|	MSEL
						bDivideFrequency	|	DF
						iCCLKSel			|	CSEL
						iDDCLKSel			|	DSEL
						iSCLK0Sel			|	S0SEL
						iSCLK1Sel			|	S1SEL
						iSysCLKSel			|	SYSSEL
						iOutClock			|	OSEL
						iClkOut				|	Selects one of the clock to CLKOUT
	Return value	:   None.
**************************************************************************************************************************/
__ramfunc void CGU_Init(int iMultiplier, \
						int bDivideFrequency, \
						int iCCLKSel, \
						int iDDCLKSel, \
						int iSCLK0Sel, \
						int iSCLK1Sel, \
						int iSysCLKSel, \
						int iOutClock, \
						int iClkOut)
{
	CGU_Settings clk_setting;

	clk_setting.ctl_MSEL    = iMultiplier;
	clk_setting.ctl_DF      = bDivideFrequency;
	clk_setting.div_CSEL    = iCCLKSel;
	clk_setting.div_SYSSEL  = iSysCLKSel;
	clk_setting.div_S0SEL   = iSCLK0Sel;
	clk_setting.div_S1SEL   = iSCLK1Sel;
	clk_setting.div_DSEL    = iDDCLKSel;
	clk_setting.div_OSEL    = iOutClock;

	//*pREG_CGU0_PLLCTL |= BITM_CGU_PLLCTL_PLLBPCL;
	//__DSB();
	//cgu_mode();
	CGU_Init_All(0, 0, &clk_setting, iClkOut);

#ifdef ADI_ADSP_CM41X_M4
	unsigned int core_clock = (((CLKIN_CM41x)*iMultiplier)/(bDivideFrequency + 1))/iCCLKSel;
	SystemCoreClock = core_clock;
	CM41xFlash_SetPerformanceMode(core_clock);
#endif /* ADI_ADSP_CM41X_M4 */

	return;
}

/**************************************************************************************************************************
	Function name	:   CGU_Init_All
    Description		:   This function initializes the CGU to configure different clocks in system.
	Arguments		:	Parameter	|	Description									|	Valid values
						uiCguNo		|	Instance of CGU								|	0, 1
						uiClkinsel	|	CLKIN source for CGU						|	0, 1
						*pClocks	|	Pointer to Structure which holds different	|	MSEL, DF, CSEL, SYSSEL, S0SEL,
										Clock multipliers and dividers					S1SEL, DSEL, OSEL values
                        uiClkoutsel	|	Selects one of the clock to CLKOUT			|	Processor dependent
	Return value	:   Success/Error code.
**************************************************************************************************************************/
__ramfunc uint32_t CGU_Init_All(uint32_t uiCguNo, uint32_t uiClkinsel, CGU_Settings *pClocks,  uint32_t uiClkoutsel)
{
    uint32_t result = 0;
#ifdef __ADSPCM40X__
    CGU_Freq_Check_Round(pClocks, 30);	// Second parameter is CLKIN value. It is ignored inside this function and 
										// is taken from CGUInit.h file
    Active_To_Fullon(0);
    uint32_t dActionFlags = BITM_ROM_SYSCTRL_CGU_CTL | BITM_ROM_SYSCTRL_CGU_DIV ;
	if(*pREG_CGU0_STAT & BITM_CGU_STAT_PLLBP)	// Check if processor is in Active mode
	{
		if(!(*pREG_CGU0_STAT & BITM_CGU_STAT_PLLEN) )	// Check if PLL is disabled
		{
			ActivePLLDis_To_Active(0);
		}
		Active_To_Fullon(0);
	}  
    CGU0_write(dActionFlags, pClocks, uiClkoutsel);
    return result;
#endif /* __ADSPCM40X__ */

#if defined(ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4)
    CGU_Freq_Check_Round(pClocks, 25);	// Second parameter is CLKIN value. It is ignored inside this function and 
										// is taken from CGUInit.h file
    uint32_t dActionFlags = BITM_ROM_SYSCTRL_CGU_CTL | BITM_ROM_SYSCTRL_CGU_DIV ;
	if(*pREG_CGU0_STAT & BITM_CGU_STAT_PLLBP)	// Check if processor is in Active mode
	{
		if(!(*pREG_CGU0_STAT & BITM_CGU_STAT_PLLEN) )	// Check if PLL is disabled
		{
			ActivePLLDis_To_Active(0);
		}
		Active_To_Fullon(0);
	}  
    CGU0_write(dActionFlags, pClocks, uiClkoutsel);
    return result;
#endif /* defined(ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4) */

}

/**************************************************************************************************************************
	Function name	:	CGU0_write
    Description		:	Performs a CGU write operation. This function performs the write operation to configure new 
						frequencies as requested by the user
	Arguments		:	Parameter		|	Description									|	Valid values
						dActionFlags	|	Specifies the action requested by the user
						*pSyscontrol	|	Pointer to the ROM structure
						*reserved		|	Reserved for future use
	Return value	:   Status	|	#0															- Success
									#BITM_ROM_SYSCTRL_READ_ERR | BITM_ROM_SYSCTRL_CGU_STAT_ERR	- Error due to PLL disabled
									#BITM_CGU_STAT_WDIVERR | BITM_CGU_STAT_WDFMSERR				- CGU status error occurred
**************************************************************************************************************************/
__ramfunc uint32_t CGU0_write(uint32_t dActionFlags, CGU_Settings *pCGU_Settings, uint32_t uiClkOutSel)
{
	uint32_t dNewCguDiv;												// variable to hold the new CGU-DIV value
	uint8_t dPllBypassed  = (*pREG_CGU0_STAT & BITM_CGU_STAT_PLLBP);	// Variable to hold the status of PLL Bypass
	uint8_t dPllEnabled   = (*pREG_CGU0_STAT & BITM_CGU_STAT_PLLEN);	// Variable to hold the status of PLL Enable

	// Check if write to CGU_DIV register is requested
	if( dActionFlags & BITM_ROM_SYSCTRL_CGU_DIV)
	{
		dNewCguDiv = 	((OSEL(pCGU_Settings->div_OSEL)) 		|
						(SYSSEL(pCGU_Settings->div_SYSSEL )) 	|
						(CSEL(pCGU_Settings->div_CSEL )) 		|
						(S0SEL(pCGU_Settings->div_S0SEL)) 		|
						(S1SEL(pCGU_Settings->div_S1SEL)) 		|
						(DSEL(pCGU_Settings->div_DSEL )))		&
						(~BITM_CGU_DIV_LOCK);

		// Check if PLL is not bypassed
		if(!dPllBypassed)
		{
			// Set the Align and Update bits
			dNewCguDiv 	|= (BITM_CGU_DIV_UPDT)  ;
		}

		// Check if disabling the auto handling of ALGN and UPDT fields is requested
		if( !(dActionFlags & BITM_ROM_SYSCTRL_CGU_AUTO_DIS))
		{
			if(!dPllBypassed)
			{
				// Set the Align and Update bits
				dNewCguDiv 	|= (BITM_CGU_DIV_ALGN | BITM_CGU_DIV_UPDT);
			}

			// Check if new values involve a frequency change
			if( ((dNewCguDiv) & (DIV_MASK)) == ((*pREG_CGU0_DIV) & (DIV_MASK)) )
			{
				// Clear the Flag for write to DIV register
				dActionFlags 	&=  (~BITM_ROM_SYSCTRL_CGU_DIV);
			}
		}
	}

	// Check if write to CGU_CTL register is requested
	if( dActionFlags & BITM_ROM_SYSCTRL_CGU_CTL)
	{
		uint32_t dNewCguCtl  = (MSEL( pCGU_Settings->ctl_MSEL )| DF( pCGU_Settings->ctl_DF ) );

		// Check if new values involve a frequecy change
		if( ((dNewCguCtl) & (CTL_MASK)) == ((*pREG_CGU0_CTL) & (CTL_MASK)) )
		{
			// Clear the Flag for write to CTL register
			dActionFlags 	&=  (~BITM_ROM_SYSCTRL_CGU_CTL);
		}
	}

	// Program the CTL and DIV registers
	Program_Cgu0(dActionFlags, dPllBypassed, dPllEnabled, dNewCguDiv, pCGU_Settings);

	*pREG_CGU0_CLKOUTSEL  = uiClkOutSel;

	return 0;
}

/**************************************************************************************************************************
	Function name	:	Program_Cgu0
	Description		:	Program the CGU. This function programs the CGU_CTL and CGU_CTL registers
	Arguments		:	Parameter		|	Description									|	Valid values
						dActionFlags	|	Specifies the action requested by the user
						*pSyscontrol	|	Pointer to the ROM structure
						*reserved		|	Reserved for future use
	Return value	:	None.
**************************************************************************************************************************/
__ramfunc void Program_Cgu0(uint32_t dActionFlags, uint32_t dPllBypassed, uint32_t dPllEnabled, uint32_t dNewCguDiv, CGU_Settings *pCGU_Settings)
{
	// Check if CGU_CTL write is not requested
	if( !(dActionFlags & BITM_ROM_SYSCTRL_CGU_CTL) )
	{
		// Check if CGU_DIV needs to be written
		if( dActionFlags & BITM_ROM_SYSCTRL_CGU_DIV)
		{
			// Check if PLL is not bypassed or disabled
			if( (!dPllBypassed) && (dPllEnabled) )
			{
				// Check if clocks are aligned before modyfying the DIV register
				while(*pREG_CGU0_STAT & BITM_CGU_STAT_CLKSALGN);
				// !!!!!! No Status bit to know error condition  !!!!!
				// !!!!!! Decide if this loop needs to be broken !!!!!
			}

			// Update the new Divider values
			*pREG_CGU0_DIV = dNewCguDiv;
			*pREG_CGU0_CTL =  (MSEL( pCGU_Settings->ctl_MSEL ) | DF( pCGU_Settings->ctl_DF ) ) & (~BITM_CGU_CTL_LOCK);

			// Check if PLL is not bypassed or disabled
			if(  (!dPllBypassed) && (dPllEnabled) )
			{
				// Wait till clocks are aligned
				while(*pREG_CGU0_STAT & BITM_CGU_STAT_CLKSALGN);
			}
		}
	}// end of CGU_DIV Write

	// Update both CGU_CTL and CGU_DIV registers
	else
	{
		// Check if PLL is not bypassed or disabled
		if(  (!dPllBypassed) && (dPllEnabled) )
		{
			while( !((*pREG_CGU0_STAT & (BITM_CGU_STAT_PLLEN | BITM_CGU_STAT_PLOCK | BITM_CGU_STAT_CLKSALGN) ) 
						== ((BITM_CGU_STAT_PLLEN | BITM_CGU_STAT_PLOCK) & (~BITM_CGU_STAT_CLKSALGN))));
		}

		// Check if PLL is enabled , PLL is not locking and Clocks are aligned
		if( dActionFlags & BITM_ROM_SYSCTRL_CGU_DIV)
		{
			// Clear the Align and Update bit, since CTL is also written
			*pREG_CGU0_DIV = dNewCguDiv & (~BITM_CGU_DIV_ALGN) & (~BITM_CGU_DIV_UPDT);
			//dNewCguDiv & (~BITM_CGU_DIV_ALGN) & (~BITM_CGU_DIV_UPDT);  
		}
    
		*pREG_CGU0_CTL =  (MSEL( pCGU_Settings->ctl_MSEL ) | DF( pCGU_Settings->ctl_DF ) ) & (~BITM_CGU_CTL_LOCK);

		// Check if PLL is not bypassed or disabled
		if(  (!dPllBypassed) && (dPllEnabled) )
		{
			// Wait till PLL is locked and clocks are aligned
			while( !((*pREG_CGU0_STAT & (BITM_CGU_STAT_PLOCK | BITM_CGU_STAT_CLKSALGN) )
						== (BITM_CGU_STAT_PLOCK & (~BITM_CGU_STAT_CLKSALGN))));
		}
	}// end of CGU_DIV and CGU_CTL Write

	return;
}

/**************************************************************************************************************************
	Function name	:	CGU_Freq_Check_Round
	Description		:	This function check round the user frequencies if they are out of spec
	Arguments		:	Parameter	|	Description									|	Valid values
					*	pClocks		|	Pointer to Structure which holds different	|	MSEL, DF, CSEL, SYSSEL, S0SEL,
										Clock multipliers and dividers					S1SEL, DSEL, OSEL values
	Return value	:	None.
**************************************************************************************************************************/
__ramfunc void CGU_Freq_Check_Round(CGU_Settings *pClocks, float uiClkinValue)
{
#ifdef __ADSPCM40X__
    float uiClkinVal   = (float)CLKIN_CM40x/1000000;

    uint32_t uiPllclk_Max   = PLLCLK_MAX_CM40x;
    uint32_t uiCclk_Max     = CCLK_MAX_CM40x;
    uint32_t uiSysclk_Max   = SYSCLK_MAX_CM40x;
    //uint32_t uiS0clk_Max    = 0;
    //uint32_t uiS1clk_Max    = 0;
    uint32_t uiDclk_Max     = DCLK_MAX_CM40x;
#endif /* __ADSPCM40X__ */

#if defined(ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4)
    float uiClkinVal   = (float)CLKIN_CM41x/1000000;

    uint32_t uiPllclk_Max   = PLLCLK_MAX_CM41x;
    uint32_t uiCclk_Max     = CCLK_MAX_CM41x;
    uint32_t uiSysclk_Max   = SYSCLK_MAX_CM41x;
    uint32_t uiS0clk_Max    = S0CLK_MAX_CM41x;
    //uint32_t uiS1clk_Max    = 0;
    uint32_t uiDclk_Max     = DCLK_MAX_CM41x;
#endif /* defined(ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4) */


    float Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
    float Core_Clock   = Pll_Clock/pClocks->div_CSEL;
    float Sys_Clock    = Pll_Clock/pClocks->div_SYSSEL;
    float S0_Clock     = Sys_Clock/pClocks->div_S0SEL;
    float S1_Clock     = Sys_Clock/pClocks->div_S1SEL;
    float Ddr_Clock    = Pll_Clock/pClocks->div_DSEL;
    float Out_Clock    = Pll_Clock/pClocks->div_OSEL;

	// If PLL clock is out of spec reduce MSEL to make PLL clock within the spec
    if( Pll_Clock > uiPllclk_Max)
    {
        while(Pll_Clock > uiPllclk_Max)
        {
            pClocks->ctl_MSEL--;
            Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
        }

        // Recalculate all the clocks
        Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
        Core_Clock   = Pll_Clock/pClocks->div_CSEL;
        Sys_Clock    = Pll_Clock/pClocks->div_SYSSEL;
        S0_Clock     = Sys_Clock/pClocks->div_S0SEL;
        S1_Clock     = Sys_Clock/pClocks->div_S1SEL;
        Ddr_Clock    = Pll_Clock/pClocks->div_DSEL;
        Out_Clock    = Pll_Clock/pClocks->div_OSEL;

    }

	// If Core clock is out of spec reduce MSEL to make Core clock within the spec
    if( Core_Clock > uiCclk_Max)
    {
        while(Core_Clock > uiCclk_Max)
        {
            pClocks->ctl_MSEL--;
            Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
            Core_Clock   = Pll_Clock/pClocks->div_CSEL;
        }

        // Recalculate all the clocks
		 Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
		 Core_Clock   = Pll_Clock/pClocks->div_CSEL;
		 Sys_Clock    = Pll_Clock/pClocks->div_SYSSEL;
		 S0_Clock     = Sys_Clock/pClocks->div_S0SEL;
		 S1_Clock     = Sys_Clock/pClocks->div_S1SEL;
		 Ddr_Clock    = Pll_Clock/pClocks->div_DSEL;
		 Out_Clock    = Pll_Clock/pClocks->div_OSEL;
    }

	// If Sys clock is out of spec reduce MSEL to make Sys clock within the spec
    if( Sys_Clock > uiSysclk_Max)
    {
        while(Sys_Clock > uiSysclk_Max)
        {
            pClocks->ctl_MSEL--;
            Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
            Sys_Clock    = Pll_Clock/pClocks->div_SYSSEL;
        }

        // Recalculate all the clocks
		 Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
		 Core_Clock   = Pll_Clock/pClocks->div_CSEL;
		 Sys_Clock    = Pll_Clock/pClocks->div_SYSSEL;
		 S0_Clock     = Sys_Clock/pClocks->div_S0SEL;
		 S1_Clock     = Sys_Clock/pClocks->div_S1SEL;
		 Ddr_Clock    = Pll_Clock/pClocks->div_DSEL;
		 Out_Clock    = Pll_Clock/pClocks->div_OSEL;
    }

#if defined (ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4)
	// If S0 clock is out of spec reduce MSEL to make S0 clock within the spec
    if( S0_Clock > uiS0clk_Max)
    {
        while(S0_Clock > uiS0clk_Max)
        {
            pClocks->ctl_MSEL--;
            Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
            S0_Clock     = Sys_Clock/pClocks->div_S0SEL;
        }

        // Recalculate all the clocks
		 Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
		 Core_Clock   = Pll_Clock/pClocks->div_CSEL;
		 Sys_Clock    = Pll_Clock/pClocks->div_SYSSEL;
		 S0_Clock     = Sys_Clock/pClocks->div_S0SEL;
		 S1_Clock     = Sys_Clock/pClocks->div_S1SEL;
		 Ddr_Clock    = Pll_Clock/pClocks->div_DSEL;
		 Out_Clock    = Pll_Clock/pClocks->div_OSEL;
    }
#endif /* defined (ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4) */

// Note: CM40x and CM41x does not have S1 Clock
/*
	// If S1 clock is out of spec reduce MSEL to make S0 clock within the spec
    if( S1_Clock > uiS1clk_Max)
    {
    	while(S1_Clock > uiS1clk_Max)
        {
            pClocks->ctl_MSEL--;
            Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
            S1_Clock     = Sys_Clock/pClocks->div_S1SEL;
        }

        // Recalculate all the clocks
		 Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
		 Core_Clock   = Pll_Clock/pClocks->div_CSEL;
		 Sys_Clock    = Pll_Clock/pClocks->div_SYSSEL;
		 S0_Clock     = Sys_Clock/pClocks->div_S0SEL;
		 S1_Clock     = Sys_Clock/pClocks->div_S1SEL;
		 Ddr_Clock    = Pll_Clock/pClocks->div_DSEL;
		 Out_Clock    = Pll_Clock/pClocks->div_OSEL;
    }
*/

	// If Ddr_Clock is out of spec reduce MSEL to make DDR clock within the spec
    if( Ddr_Clock > uiDclk_Max)
    {
        while(Ddr_Clock > uiDclk_Max)
        {
            pClocks->ctl_MSEL--;
            Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
            Ddr_Clock    = Pll_Clock/pClocks->div_DSEL;
        }

        // Recalculate all the clocks
		 Pll_Clock    = uiClkinVal*(pClocks->ctl_MSEL)/((pClocks->ctl_DF) + 1);
		 Core_Clock   = Pll_Clock/pClocks->div_CSEL;
		 Sys_Clock    = Pll_Clock/pClocks->div_SYSSEL;
		 S0_Clock     = Sys_Clock/pClocks->div_S0SEL;
		 S1_Clock     = Sys_Clock/pClocks->div_S1SEL;
		 Ddr_Clock    = Pll_Clock/pClocks->div_DSEL;
		 Out_Clock    = Pll_Clock/pClocks->div_OSEL;
    }

	return;
}

/**************************************************************************************************************************
Function name	:	Active_To_Fullon
Description		:	This function changes the Operating mode from Active to FullOn
Arguments		:	Parameter	|	Description	|	Valid values
					uiCGU_ID	|	CGU number	|	0,1
Return value	:	None.
**************************************************************************************************************************/
__ramfunc void Active_To_Fullon(unsigned int uiCGU_ID)
{
    if(uiCGU_ID == 0)
    {
        uint32_t oldCGU0_STAT;

		// Wait Loop to ensure pre-switch conditions
        while(1)
        {
            oldCGU0_STAT = *pREG_CGU0_STAT;
            if((oldCGU0_STAT & BITM_CGU_STAT_PLLEN) && (oldCGU0_STAT & BITM_CGU_STAT_PLLBP))
            {   break; }
        }

#ifdef __ADSPCM40X__
		// PLL Disable
        *pREG_DPM0_CTL = BITM_DPM_CTL_PLLBPCL;
#endif /* __ADSPCM40X__ */
       
#if defined(ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4)
		// PLL Disable
        *pREG_CGU0_PLLCTL = BITM_CGU_PLLCTL_PLLBPCL;
#endif /* defined(ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4) */

        // Wait Loop to ensure post-switch conditions
        while(1)
        {
            oldCGU0_STAT = *pREG_CGU0_STAT;
            if ((oldCGU0_STAT & BITM_CGU_STAT_PLLEN) && 
					~(oldCGU0_STAT & BITM_CGU_STAT_PLLBP) &&
					~(oldCGU0_STAT & BITM_CGU_STAT_CLKSALGN))
            {
				break;
			}
        }
    }

	return;
}

/**************************************************************************************************************************
	Function name	:	ActivePLLDis_To_Active
	Description		:	This function changes the Operating mode from Active with PLL Disabled to Active
	Arguments		:	Parameter	|	Description	|	Valid values
						uiCGU_ID	|	CGU number	|	0,1
	Return value	:	None.
**************************************************************************************************************************/
__ramfunc void ActivePLLDis_To_Active(unsigned int uiCGU_ID)
{
	if(uiCGU_ID == 0)
	{
		uint32_t  oldCGU0_STAT;

		// Wait Loop to ensure pre-switch conditions
		while(1)
		{
			oldCGU0_STAT = *pREG_CGU0_STAT;
			if((oldCGU0_STAT & BITM_CGU_STAT_PLLBP) && ~(oldCGU0_STAT & BITM_CGU_STAT_PLLEN))
			{
				break;
			}
		}

#ifdef __ADSPCM40X__
		// PLL Enable
		*pREG_DPM0_CTL |= ((0 << BITP_DPM_CTL_PLLDIS) & BITM_DPM_CTL_PLLDIS);
#endif /* __ADSPCM40X__ */

#if defined(ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4)
		// PLL Enable
		*pREG_CGU0_PLLCTL = BITM_CGU_PLLCTL_PLLEN;
#endif /* defined(ADI_ADSP_CM41X_M0) || defined(ADI_ADSP_CM41X_M4) */

		while(1)
		{
			oldCGU0_STAT = *pREG_CGU0_STAT;
			if((oldCGU0_STAT & BITM_CGU_STAT_PLLBP) && (oldCGU0_STAT & BITM_CGU_STAT_PLLEN))
			{
				break;
			}
		}
	}

	return;
}

#ifdef ADI_ADSP_CM41X_M4
/**************************************************************************************************************************
	Function name	:	CM41xFlash_SetPerformanceMode
	Description		:	This function changes the Operating mode from Active with PLL Disabled to Active
	Arguments		:	Parameter	|	Description			|	Valid values
						core_clock	|	Core Clock (in Hz)	|	Valid CCLK
	Return value	:	None.
**************************************************************************************************************************/
__ramfunc void CM41xFlash_SetPerformanceMode(unsigned int core_clock)
{
	if(core_clock <= 75000000)
	{
		*pREG_FLC0_PRFCTL = (*pREG_FLC0_PRFCTL & (~BITM_FLC_PRFCTL_PMODE)) | ENUM_FLC_PRFCTL_A ; 
		*pREG_FLC1_PRFCTL = (*pREG_FLC1_PRFCTL & (~BITM_FLC_PRFCTL_PMODE)) | ENUM_FLC_PRFCTL_A ; 
	}
	else if(core_clock <= 150000000)
	{
		*pREG_FLC0_PRFCTL = (*pREG_FLC0_PRFCTL & (~BITM_FLC_PRFCTL_PMODE)) | ENUM_FLC_PRFCTL_B ; 
		*pREG_FLC1_PRFCTL = (*pREG_FLC1_PRFCTL & (~BITM_FLC_PRFCTL_PMODE)) | ENUM_FLC_PRFCTL_B ; 
	}
	else if(core_clock <= 225000000)
	{
		*pREG_FLC0_PRFCTL = (*pREG_FLC0_PRFCTL & (~BITM_FLC_PRFCTL_PMODE)) | ENUM_FLC_PRFCTL_C ; 
		*pREG_FLC1_PRFCTL = (*pREG_FLC1_PRFCTL & (~BITM_FLC_PRFCTL_PMODE)) | ENUM_FLC_PRFCTL_C ; 
	}
	else if(core_clock <= 240000000)
	{
		*pREG_FLC0_PRFCTL = (*pREG_FLC0_PRFCTL & (~BITM_FLC_PRFCTL_PMODE)) | ENUM_FLC_PRFCTL_E ; 
		*pREG_FLC1_PRFCTL = (*pREG_FLC1_PRFCTL & (~BITM_FLC_PRFCTL_PMODE)) | ENUM_FLC_PRFCTL_E ; 
	}
	return;
}
#endif /* ADI_ADSP_CM41X_M4 */
