#include <stdio.h>
#include "device.h"
#include "common.h"

volatile unsigned int SysTickCnt;	/* SysTick Counter */
extern uint32_t SystemCoreClock;

/**************************************************************************************************************************
	Function name	:	Local_SysTick_Config
	Description		:	System Tick Configuration - Initializes the System Timer and its interrupt, and starts the 
						System Tick Timer. Counter is in free running mode to generate periodic interrupts.
	Arguments		:	None.
	Return value	:	None.
**************************************************************************************************************************/
void Local_SysTick_Config(void)
{
	SysTick->LOAD  = SysTick_LOAD_RELOAD_Msk;							// set reload register to max ticks
	NVIC_SetPriority (SysTick_IRQn, (1UL << __NVIC_PRIO_BITS) - 1UL);	// set Priority for Systick Interrupt
	SysTick->VAL   = 0UL;												// Load the SysTick Counter Value
	SysTick->CTRL  = SysTick_CTRL_CLKSOURCE_Msk |
					 SysTick_CTRL_TICKINT_Msk   |
					 SysTick_CTRL_ENABLE_Msk;							// Enable SysTick IRQ and SysTick Timer
	return;
}

/**************************************************************************************************************************
	Function name	:	SysTick_Handler
	Description		:	ISR for System Tick Timer interrupts
	Arguments		:	None.
	Return value	:	None.
**************************************************************************************************************************/
__ramfunc void SysTick_Handler(void)
{
	SysTickCnt++;
}

union magic_u
{
   unsigned long long u64;
   unsigned int u32[2];
};

/**************************************************************************************************************************
	Function name	:	cycleCountToULL
	Description		:	Convert recorded cycle counts to unsigned long long
	Arguments		:	Parameter	|	Description							|	Valid values
						x			|	Pointer to recorded cycle count
	Return value	:	Cycle count converted to unsigned long long
**************************************************************************************************************************/
#pragma inline=forced
static unsigned long long cycleCountToULL(cycle_count_t * x)
{
	unsigned long long y, z;
	y = (unsigned long long)(x->tick);
	z = (unsigned long long)(SysTick_LOAD_RELOAD_Msk-(x->count));

	y = (y << 24) | z;
	return y;
}

/**************************************************************************************************************************
	Function name	:	subtract_cycle_count
	Description		:	Subtract recorded start time from end time
	Arguments		:	Parameter	|	Description										|	Valid values
						_start		|	Pointer to recorded cycle count for Start time
						_end		|	Pointer to recorded cycle count for End time
	Return value	:	Cycle count difference or time taken to execute a piece of code
**************************************************************************************************************************/
unsigned int subtract_cycle_count(volatile cycle_count_t * _start, volatile cycle_count_t * _end)
{
	unsigned long long start, end, cycles;
	start =  cycleCountToULL((cycle_count_t *)_start);
	end =  cycleCountToULL((cycle_count_t *)_end);
	cycles = (end - start);
	#if defined(DEBUG)
	{
		union magic_u y;
		y.u64 = cycles;
		printf("Start tick: 0x%x VAL: 0x%x\n",_start->tick, _start->count);
		printf("Stop  tick: 0x%x VAL: 0x%x\n",_end->tick, _end->count);
		printf("Cycle count: 0x%x%8.8x\n",y.u32[1],y.u32[0]);
	}
	#endif /* defined(DEBUG) */
	return (unsigned int)(cycles);
}

// IVT typedefs
typedef void  ( *IntFunc )( void );
typedef union { IntFunc __fun; void * __ptr; } IntVector;


/**************************************************************************************************************************
	Function name	:	init_platform
	Description		:	Initialize the System
	Arguments		:	None.
	Return value	:	None.
**************************************************************************************************************************/
#pragma optimize=none
void init_platform(void)
{
	SystemInit();

	__disable_irq();	// do CGU init in safe way

	#ifdef CCLK_SCLK_240_96
		CGU_Init(16, 0, 2, 8, 1, 1, 5, 10, 4);
	#elif defined CCLK_SCLK_240_80
		CGU_Init(16, 0, 2, 8, 1, 1, 6, 10, 4);
	#elif defined CCLK_SCLK_225_100
		CGU_Init(30, 0, 4, 15, 1, 1, 9, 15, 4);
	#elif defined CCLK_SCLK_200_100
		CGU_Init(20, 0, 3, 10, 1, 1, 6, 10, 4);
	#elif defined CCLK_SCLK_150_100
		CGU_Init(20, 0, 4, 10, 1, 1, 6, 10, 4);
	#elif defined CCLK_SCLK_75_75
		CGU_Init(20, 0, 8, 10, 1, 1, 8, 10, 4);
	#endif /* CCLK_SCLK_ */

	SysTickCnt = 0;

	Local_SysTick_Config();	//Setup System Timer to interrupt after max ticks

	__enable_irq();

	return;
}

/**************************************************************************************************************************
	Function name	:	verify_accuracy
	Description		:	Check if the result obtained is accurate compared to expected result
	Arguments		:	Parameter	|	Description											|	Valid values
						Result		|	Result obtained
						Expected	|	Expected result
						Tolerance	|	Maximum accepted Percentage error between
										Expected and Actual result
						pError		|	Pointer to Error between Expected and Actual result
	Return value	:	1 - Error is below Tolerance (Pass)
						0 - Error is above Tolerance (Fail)
**************************************************************************************************************************/
int verify_accuracy(float Result, float Expected, float Tolerance, float *pError)
{
	float error = (Expected - Result) / Expected * 100.0f;
	if (error < 0.0f)
		error *= -1.0f;

	*pError = error;

	if (error > Tolerance)
	{
		#if defined(DEBUG)
			printf("Obtained result %f; Expected result %f\n", Result, Expected);
		#endif /* defined(DEBUG) */
		return 0;
	}
	return 1;
}

/**************************************************************************************************************************
	Function name	:	verify_accuracy_arrays
	Description		:	Check if the result obtained in an array is accurate compared to expected result array
	Arguments		:	Parameter	|	Description													|	Valid values
						pResult		|	Pointer to array of Results obtained
						pExpected	|	Pointer to array of Expected results
						N			|	Length of pResult/pExpected array
						Tolerance	|	Maximum accepted Percentage error between
										Expected and Actual results
						pMaxError	|	Pointer to Maximum Error between Expected and Actual results
	Return value	:	1 - Maximum Error is below Tolerance (Pass)
						0 - Maximum Error is above Tolerance (Fail)
**************************************************************************************************************************/
int verify_accuracy_arrays(const float *pResult, const float *pExpected, int N,  float Tolerance, float *pMaxError)
{
	int i;
	int passfail = 1;
	float error = 0.0f;
	float max_error = 0.0f;

	for( i = 0 ; i < N ; i++ )
	{
		error = (pExpected[i] - pResult[i]) / pExpected[i] * 100.0f;
		if (error < 0)
			error *= -1.0f;
		if (error > max_error)
			max_error = error;

		#if defined(DEBUG)
		{
			unsigned int *resultint;
			unsigned int *expectedint;
			resultint = (unsigned int *)(&(pResult[i]));
			expectedint = (unsigned int *)(&(pExpected[i]));
			if (error > Tolerance)
				//printf("[%d] - Obtained %f; Expected %f\n", i, pResult[i], pExpected[i]);
				printf("[%d] - Obtained result 0x%x; Expected result 0x%x\n", i, *resultint, *expectedint);
		}
		#endif /* defined(DEBUG) */
	}

	*pMaxError = max_error;

	if (max_error > Tolerance)
		passfail = 0;

	return passfail;
}
