#ifndef __IPARK_H__
#define __IPARK_H__

#include "common.h"

/**************************************************************************************************************************
	Function name	:	ipark_xform
	Description		:	This transformation converts vectors in balanced 2-phase orthogonal rotating system into 
						orthogonal stationary reference frame.
						Implements the following equations:
							Ialpha =  Id * cos(theta) - Iq * sin(theta)
							Ibeta  =  Id * sin(theta) + Iq * cos(theta)
	Arguments		:	Parameter	|	Description							|	Valid values
						Id			|	rotating d-axis stator variable
						Iq			|	rotating q-axis stator variable
						theta		|	rotating angle (from Ialpha to Id)
						pIalpha		|	Pointer to stationary alpha-axis stator variable
						pIbeta		|	Pointer to stationary beta-axis stator variable
	Return value	:	None.
**************************************************************************************************************************/
void ipark_xform(float Id, float Iq, float theta, float * pIalpha, float * pIbeta)
{
	float stheta, ctheta;

#if TEST_MODE==M4_CMSISLIB
	theta = theta * 57.2957795131f;								// Convert radians to degrees
	arm_sin_cos_f32(theta,&stheta,&ctheta);						// Call CMSIS sin-cos function
	arm_inv_park_f32(Id, Iq, pIalpha, pIbeta, stheta, ctheta);	// Call CMSIS Inverse Park transform function
#else // TEST_MODE==M4_CMSISLIB
	stheta = sinf(theta);										// Call sinf() from math.h or adi_math.h
	ctheta = cosf(theta);										// Call cosf() from math.h or adi_math.h
	*pIalpha =  Id * ctheta - Iq * stheta;
	*pIbeta  =  Id * stheta + Iq * ctheta;
#endif // TEST_MODE==M4_CMSISLIB

	return;
}

#if TEST_MODE==MATH_M4_CODEINTERLEAVE

/**************************************************************************************************************************
	Function name	:	ipark_xform_interl
	Description		:	Implements Inverse Park Transform with Cortex-M4 and Math Unit interleaved
	Arguments		:	Parameter	|	Description										|	Valid values
						p_Id		|	Pointer to rotating d-axis stator variable
						p_Iq		|	Pointer to rotating q-axis stator variable
						p_theta		|	Pointer to rotating angle (from Ialpha to Id)
						p_Ialpha	|	Pointer to stationary alpha-axis stator variable
						p_Ibeta		|	Pointer to stationary beta-axis stator variable
						N			|	Number of Samples
	Return value	:	None.
**************************************************************************************************************************/
#pragma inline=forced
void ipark_xform_interl(float * p_Id, float * p_Iq, float * p_theta, float * p_Ialpha, float * p_Ibeta, unsigned int N)
{
	float theta,stheta,ctheta;
	float Id_temp,Iq_temp,Ialpha_temp,Ibeta_temp;
	unsigned int idx;

	theta = p_theta[0];									// Read theta from memory
	cosf_write(theta);									// Start cosf(theta[0]) computation on Math Unit
	for( idx = 0 ; idx < (N-1) ; idx++ )
	{
		Id_temp = p_Id[idx];							// Read Id from memory
		Iq_temp = p_Iq[idx];							// Read Iq from memory
		ctheta = cosf_read();							// Read cosf(theta[idx]) result from Math Unit
		sinf_write(theta);								// Start sinf(theta[idx]) computation on Math Unit
		theta = p_theta[idx+1];							// Read theta from memory
		Ialpha_temp = Id_temp * ctheta;					// Calculate Id*cos(theta) on M4 core
		Ibeta_temp = Iq_temp * ctheta;					// Calculate Iq*cos(theta) on M4 core
		stheta = sinf_read();							// Read sinf(theta[idx]) result from Math Unit
		cosf_write(theta);								// Start cosf(theta[idx+1]) computation on Math Unit
		p_Ialpha[idx] = Ialpha_temp - Iq_temp * stheta;	// Calculate final Ialpha on M4 core
		p_Ibeta[idx] = Ibeta_temp + Id_temp * stheta;	// Calculate final Ibeta on M4 core
	}
	Id_temp = p_Id[N-1];								// Read Id from memory
	Iq_temp = p_Iq[N-1];								// Read Iq from memory
	ctheta = cosf_read();								// Read cosf(theta[N-1]) result from Math Unit
	sinf_write(theta);									// Start sinf(theta[N-1]) computation on Math Unit
	Ialpha_temp = Id_temp * ctheta;						// Calculate Id*cos(theta) on M4 core
	Ibeta_temp = Iq_temp * ctheta;						// Calculate Iq*cos(theta) on M4 core
	stheta = sinf_read();								// Read sinf(theta[N-1]) result from Math Unit
	p_Ialpha[N-1] = Ialpha_temp - Iq_temp * stheta;		// Calculate final Ialpha on M4 core
	p_Ibeta[N-1] = Ibeta_temp + Id_temp * stheta;		// Calculate final Ibeta on M4 core

	return;
}

#endif //TEST_MODE==MATH_M4_CODEINTERLEAVE

#define NUM_SAMPLES    (128)	// Number of computations

//Randomly generated test vector for Id
static unsigned int std_Id[128] @ "RAM_code_region" = {
  0x3ff33388 /*1.900010*/,  0x3d5df040 /*0.054184*/,  0x3f6a3742 /*0.914906*/,  0x3f0c3fd4 /*0.547849*/,
  0xbf9b9c72 /*-1.215712*/,  0xc01b0d2b /*-2.422679*/,  0xc03b4682 /*-2.926178*/,  0x3fa19d84 /*1.262619*/,
  0xbfcca32b /*-1.598729*/,  0x405c10b0 /*3.438519*/,  0xc089fdb4 /*-4.312220*/,  0xbf66a36b /*-0.900931*/,
  0x40733239 /*3.799940*/,  0xbfe710b2 /*-1.805197*/,  0x4099c825 /*4.805682*/,  0xc084cc68 /*-4.149952*/,
  0x408270f7 /*4.076290*/,  0xc07e64da /*-3.974905*/,  0x4087086b /*4.219778*/,  0x3d9aa600 /*0.075512*/,
  0x406e43de /*3.722892*/,  0xbfd56d74 /*-1.667403*/,  0x3ff648bb /*1.924095*/,  0x3f11c846 /*0.569462*/,
  0xbfb0bfa0 /*-1.380848*/,  0xc095c311 /*-4.680062*/,  0x40657275 /*3.585111*/,  0xc0805331 /*-4.010155*/,
  0x407152be /*3.770675*/,  0xbf01e5ac /*-0.507411*/,  0xbf2d9643 /*-0.678074*/,  0x3f8805e0 /*1.062679*/,
  0x4088e876 /*4.278377*/,  0x3fd24920 /*1.642857*/,  0xbf85eeae /*-1.046346*/,  0xbf1d84fb /*-0.615310*/,
  0x3fc2b857 /*1.521251*/,  0x40893c81 /*4.288636*/,  0x408fb9d3 /*4.491434*/,  0xbff69c3a /*-1.926643*/,
  0x3f76ff0e /*0.964829*/,  0x40352b33 /*2.830762*/,  0xbfcf5236 /*-1.619696*/,  0x40435c9e /*3.052528*/,
  0x408d80c0 /*4.421967*/,  0xc08aba80 /*-4.335266*/,  0x4064891c /*3.570868*/,  0x4098b5ba /*4.772183*/,
  0x40795fa4 /*3.896462*/,  0x3ee7cfac /*0.452756*/,  0x406932aa /*3.643717*/,  0xbed83434 /*-0.422273*/,
  0x404023f3 /*3.002194*/,  0x406f2bec /*3.737056*/,  0x404df6ba /*3.218184*/,  0xc049229e /*-3.142738*/,
  0xc084652b /*-4.137350*/,  0x3fb0d6e6 /*1.381558*/,  0xc02a59a1 /*-2.661721*/,  0xbebedd5e /*-0.372783*/,
  0xc09da02a /*-4.925801*/,  0x3facd041 /*1.350105*/,  0xbf4998e8 /*-0.787489*/,  0x40912bb0 /*4.536583*/,
  0xc03985dd /*-2.898795*/,  0x4096a3e3 /*4.707506*/,  0xc018cc62 /*-2.387475*/,  0x4064856a /*3.570643*/,
  0x3f503630 /*0.813327*/,  0x4004af08 /*2.073183*/,  0xc008f9d2 /*-2.140248*/,  0xbfe8b2fc /*-1.817962*/,
  0x3fb84214 /*1.439517*/,  0x406573a4 /*3.585183*/,  0x3fd82de0 /*1.688900*/,  0xbf11896c /*-0.568503*/,
  0xc08e1d16 /*-4.441051*/,  0x403191d8 /*2.774527*/,  0x3f7269bc /*0.946926*/,  0xc07eaaf1 /*-3.979183*/,
  0xc0004912 /*-2.004460*/,  0x40903aed /*4.507193*/,  0x3fd41f2a /*1.657201*/,  0x408f4592 /*4.477242*/,
  0x4072d74c /*3.794391*/,  0x40008df6 /*2.008665*/,  0xbf9ebc7e /*-1.240127*/,  0x3f9141d2 /*1.134821*/,
  0x406868f4 /*3.631406*/,  0xc068d9b1 /*-3.638287*/,  0xbf1a67e9 /*-0.603148*/,  0xc0104623 /*-2.254281*/,
  0xc0487118 /*-3.131903*/,  0x3d7c7e20 /*0.061644*/,  0x3f348192 /*0.705102*/,  0x3fdd384e /*1.728281*/,
  0x3f9e3e00 /*1.236267*/,  0xc08c6276 /*-4.387019*/,  0x3f012b12 /*0.504563*/,  0x3f23b8e4 /*0.639540*/,
  0x3ebb4bbc /*0.365812*/,  0xc07d4a5c /*-3.957664*/,  0x3f7ecde2 /*0.995329*/,  0xc00f271a /*-2.236762*/,
  0xbfc9c870 /*-1.576429*/,  0x4019c8fc /*2.402892*/,  0x40946dec /*4.638418*/,  0xbff150a2 /*-1.885273*/,
  0xbf9e398c /*-1.236131*/,  0x3f18c2ae /*0.596721*/,  0xbe8c1752 /*-0.273615*/,  0x4096d69d /*4.713698*/,
  0x3fabafe0 /*1.341305*/,  0xbfba4e97 /*-1.455523*/,  0xbfa28f16 /*-1.269992*/,  0xbfccd308 /*-1.600190*/,
  0xc09f24b7 /*-4.973232*/,  0x4015d26c /*2.340968*/,  0x3f67924e /*0.904576*/,  0x3f7f69f0 /*0.997710*/,
  0x40715900 /*3.771057*/,  0xbff71ac2 /*-1.930504*/,  0xc09bc43f /*-4.867706*/,  0x409fad9f /*4.989944*/,
  0x3eb11c14 /*0.345917*/,  0x4053935c /*3.305869*/,  0x408930c6 /*4.287204*/,  0xc09f0d32 /*-4.970361*/ };

//Randomly generated test vector for Iq
static unsigned int std_Iq[128] @ "RAM_code_region" = {
  0xbefb674c /*-0.491022*/,  0x4010e54d /*2.263995*/,  0xbffa3546 /*-1.954751*/,  0x408bb2da /*4.365582*/,
  0xc0780d3b /*-3.875808*/,  0xbfdf2e8d /*-1.743608*/,  0xc0722b23 /*-3.783883*/,  0x4085648d /*4.168524*/,
  0x4073cb2e /*3.809276*/,  0x407ed7f1 /*3.981930*/,  0xc01e3114 /*-2.471745*/,  0x3e935d14 /*0.287820*/,
  0x4092dcd7 /*4.589458*/,  0xc0247757 /*-2.569784*/,  0xbf6f0c3b /*-0.933780*/,  0x4094a752 /*4.645425*/,
  0x4084d344 /*4.150789*/,  0x40069dd8 /*2.103384*/,  0xc0804f02 /*-4.009645*/,  0x3ff4f9c0 /*1.913872*/,
  0x40681540 /*3.626297*/,  0xc020de2e /*-2.513561*/,  0xc0122745 /*-2.283647*/,  0x409610d2 /*4.689553*/,
  0xc07f4e2b /*-3.989146*/,  0xbf3ee8a8 /*-0.745738*/,  0x407fbd1f /*3.995918*/,  0x408a687b /*4.325254*/,
  0xc07954ea /*-3.895808*/,  0x40848540 /*4.141266*/,  0xbf94234d /*-1.157327*/,  0x403ac054 /*2.917989*/,
  0xc082acd2 /*-4.083596*/,  0xbfdb1b72 /*-1.711775*/,  0xc09e8320 /*-4.953506*/,  0x40867836 /*4.202174*/,
  0x3f9247bc /*1.142814*/,  0xc03c0e94 /*-2.938390*/,  0xc07ada22 /*-3.919564*/,  0xc0139707 /*-2.306093*/,
  0xc0659ba2 /*-3.587624*/,  0x3e4f0648 /*0.202172*/,  0x3f69e602 /*0.913666*/,  0xc0335cfe /*-2.802551*/,
  0x3fa09ace /*1.254724*/,  0x409b211b /*4.847791*/,  0x3ebaecd0 /*0.365088*/,  0xc05b1055 /*-3.422872*/,
  0x404d366f /*3.206447*/,  0x404971a4 /*3.147561*/,  0xc002e4ce /*-2.045215*/,  0x3e417988 /*0.188940*/,
  0xc095dc5a /*-4.683148*/,  0xbfb3d988 /*-1.405076*/,  0xbff6eb16 /*-1.929049*/,  0xc097cf11 /*-4.744027*/,
  0x4017117f /*2.360443*/,  0x4083a203 /*4.113527*/,  0x40825120 /*4.072403*/,  0xc01b2302 /*-2.424012*/,
  0xbe6eab38 /*-0.233075*/,  0xc080d95b /*-4.026533*/,  0xc011050a /*-2.265933*/,  0x40333265 /*2.799951*/,
  0x405d9ecc /*3.462817*/,  0xc05ca77b /*-3.447722*/,  0x3f057532 /*0.521320*/,  0x40536058 /*3.302755*/,
  0xc065ec55 /*-3.592550*/,  0x40883544 /*4.256502*/,  0xc011919c /*-2.274512*/,  0x3f01b8ac /*0.506724*/,
  0xbe1b8444 /*-0.151872*/,  0x403f9cf6 /*2.993955*/,  0xc09f6e23 /*-4.982194*/,  0x408a0008 /*4.312504*/,
  0xc0915231 /*-4.541283*/,  0xc07e5bca /*-3.974352*/,  0x401d00e6 /*2.453180*/,  0xbfc2bc28 /*-1.521367*/,
  0x40156e3a /*2.334853*/,  0x409fa9c2 /*4.989472*/,  0xbfd3b477 /*-1.653945*/,  0xc05802e0 /*-3.375175*/,
  0x409a679d /*4.825148*/,  0x3fb510fd /*1.414581*/,  0xc06a0e4c /*-3.657123*/,  0x3f21de48 /*0.632298*/,
  0xc0487241 /*-3.131974*/,  0xc0872804 /*-4.223635*/,  0x3f7edb7a /*0.995536*/,  0x408a593f /*4.323394*/,
  0xbf48d10b /*-0.784440*/,  0xc0588890 /*-3.383335*/,  0xbf2582d2 /*-0.646527*/,  0x3ed6c450 /*0.419466*/,
  0x3f14a2fa /*0.580612*/,  0x409482fb /*4.640989*/,  0xbea82064 /*-0.328372*/,  0xc0819048 /*-4.048862*/,
  0xbffe62b0 /*-1.987387*/,  0x3f022346 /*0.508351*/,  0xc080c04a /*-4.023473*/,  0xc08bed52 /*-4.372720*/,
  0xbfa20a32 /*-1.265936*/,  0xc09ffcfb /*-4.999631*/,  0xc028104e /*-2.625995*/,  0x3e43e8f8 /*0.191318*/,
  0xbfe4195e /*-1.782024*/,  0x408dacbf /*4.427337*/,  0xc00b0d3c /*-2.172683*/,  0xc0373b96 /*-2.863012*/,
  0x3f3683b6 /*0.712947*/,  0xc01aec15 /*-2.420659*/,  0x40760b9e /*3.844459*/,  0xc09de0d5 /*-4.933695*/,
  0xbf9787e0 /*-1.183834*/,  0xbfe9e224 /*-1.827214*/,  0x3f307d90 /*0.689416*/,  0xc003c2fe /*-2.058776*/,
  0xbf0a97a1 /*-0.541376*/,  0x3de67120 /*0.112520*/,  0xc02a7aa7 /*-2.663736*/,  0x409dfc6e /*4.937064*/,
  0x3e221868 /*0.158296*/,  0xc08ca027 /*-4.394550*/,  0x3e1d6ed0 /*0.153743*/,  0x3e9fe598 /*0.312299*/ };

//Randomly generated test vector for theta
static unsigned int std_theta[128] @ "RAM_code_region" = {
  0xc039dee6 /*-2.904230*/,  0xbfd038bb /*-1.626731*/,  0x403b16b1 /*2.923260*/,  0xbf92881f /*-1.144779*/,
  0xbf3f85d5 /*-0.748136*/,  0x3f8165c4 /*1.010918*/,  0x401f18b8 /*2.485884*/,  0xbf21472e /*-0.629992*/,
  0xbf7905d3 /*-0.972745*/,  0xbf211109 /*-0.629166*/,  0xbb79a890 /*-0.003809*/,  0x3f86fb79 /*1.054549*/,
  0xbf914064 /*-1.134778*/,  0xbfcc7ce6 /*-1.597562*/,  0x3f3089a1 /*0.689600*/,  0x3d12b559 /*0.035817*/,
  0x3edf50ca /*0.436163*/,  0x3f2c8c3e /*0.674015*/,  0x3f1f1865 /*0.621466*/,  0x4045ba00 /*3.089478*/,
  0xc0130795 /*-2.297338*/,  0x3e6fa2c4 /*0.234019*/,  0xc03ee294 /*-2.982579*/,  0xbf0691b3 /*-0.525661*/,
  0xbfcb31a2 /*-1.587452*/,  0xbfff8517 /*-1.996249*/,  0xc0281eaf /*-2.626873*/,  0x40387d19 /*2.882635*/,
  0x3d90aff8 /*0.070648*/,  0x4029261a /*2.642951*/,  0x3f5a0fcc /*0.851804*/,  0x3d03440c /*0.032047*/,
  0x40160279 /*2.343901*/,  0x3f8983d7 /*1.074336*/,  0x4042222e /*3.033336*/,  0xc0294ead /*-2.645427*/,
  0xbfac9cd2 /*-1.348536*/,  0xbfaed14f /*-1.365763*/,  0xbc26fd39 /*-0.010192*/,  0xc03cd409 /*-2.950442*/,
  0x3fbd3a25 /*1.478337*/,  0x3f61711f /*0.880632*/,  0xbf846e0a /*-1.034608*/,  0xbffb1553 /*-1.961588*/,
  0x3fa63204 /*1.298401*/,  0x40168402 /*2.351807*/,  0xbfb55c9b /*-1.416889*/,  0x40106898 /*2.256384*/,
  0xbfd32d73 /*-1.649825*/,  0xbf870a3d /*-1.055000*/,  0xbedbd105 /*-0.429329*/,  0x3fd666b8 /*1.675010*/,
  0x3eb62e52 /*0.355822*/,  0xc01a877b /*-2.414519*/,  0x3e84bb84 /*0.259243*/,  0x3f8b2c2a /*1.087285*/,
  0x3f16408f /*0.586923*/,  0x3f9695e8 /*1.176450*/,  0x4033bec1 /*2.808518*/,  0x40135bfd /*2.302490*/,
  0x3f89cbab /*1.076528*/,  0x3e6f1692 /*0.233485*/,  0x3f42ad9d /*0.760462*/,  0xc0013d5f /*-2.019371*/,
  0x3f73e741 /*0.952747*/,  0xc02790b9 /*-2.618208*/,  0xbf38b052 /*-0.721440*/,  0x3f9f8b2c /*1.246435*/,
  0x4014e214 /*2.326299*/,  0xc029c8cb /*-2.652880*/,  0xbfe8ae18 /*-1.817813*/,  0x40075c34 /*2.115003*/,
  0xc00ef59f /*-2.233742*/,  0xbff00e28 /*-1.875432*/,  0x3fefeed0 /*1.874475*/,  0x403c159a /*2.938818*/,
  0xc01cdae2 /*-2.450860*/,  0x402ab29c /*2.667151*/,  0xc02beead /*-2.686443*/,  0xbfb52150 /*-1.415079*/,
  0x3db87d87 /*0.090083*/,  0xbf075452 /*-0.528630*/,  0xbf013275 /*-0.504676*/,  0x3cc0428c /*0.023469*/,
  0x3f9c632b /*1.221776*/,  0x3f9218c9 /*1.141381*/,  0xc00be48b /*-2.185824*/,  0x3f6d9d95 /*0.928186*/,
  0xbfcc8ef8 /*-1.598113*/,  0xc023943c /*-2.555923*/,  0x40228131 /*2.539135*/,  0xc01d360a /*-2.456423*/,
  0x40391c73 /*2.892361*/,  0x3f3c22e6 /*0.734908*/,  0x3fe787c1 /*1.808830*/,  0xbfacdc6d /*-1.350477*/,
  0x3ff64db1 /*1.924246*/,  0x3f4c4b07 /*0.798020*/,  0x3cb947c4 /*0.022617*/,  0x3faf14b6 /*1.367820*/,
  0xbfafd33a /*-1.373634*/,  0xbff7fbbc /*-1.937370*/,  0xc005935b /*-2.087119*/,  0xbe9a2f2b /*-0.301141*/,
  0xc03f0cdd /*-2.985160*/,  0x3f7ee2a3 /*0.995646*/,  0x3e90ee8e /*0.283070*/,  0x40317707 /*2.772890*/,
  0xc043afb9 /*-3.057600*/,  0xc00f1618 /*-2.235723*/,  0x403013ee /*2.751216*/,  0x3db2cba2 /*0.087302*/,
  0x3fa0d714 /*1.256564*/,  0x3ff8de1a /*1.944278*/,  0xc02d33f8 /*-2.706297*/,  0x3fffa6e3 /*1.997280*/,
  0xbfe95a29 /*-1.823064*/,  0x3e877d3f /*0.264627*/,  0xc039d150 /*-2.903400*/,  0xc001a887 /*-2.025911*/,
  0x3db94f08 /*0.090483*/,  0x3f80e124 /*1.006871*/,  0xbfafe3f8 /*-1.374145*/,  0x3ec4a9be /*0.384108*/,
  0x3f1fda44 /*0.624424*/,  0x3ff3070c /*1.898653*/,  0x4013da9a /*2.310217*/,  0xbfa439a9 /*-1.283010*/ };

//Expected Ialpha, corresponding to randomly generated Id, Iq and theta
static unsigned int std_Ialpha[128] @ "RAM_code_region" = {
  0xbffb293b /*-1.962196*/,  0x401079a9 /*2.257426*/,  0xbef08753 /*-0.469782*/,  0x408674f9 /*4.201779*/,
  0xc061c570 /*-3.527676*/,  0x3e435400 /*0.190750*/,  0x40940be0 /*4.626450*/,  0x405e7805 /*3.476075*/,
  0x400fdee5 /*2.247979*/,  0x40a3f287 /*5.123355*/,  0xc08a4a95 /*-4.321604*/,  0xbf31ed54 /*-0.695028*/,
  0x40b87a2c /*5.764914*/,  0xc02150bd /*-2.520553*/,  0x4089a765 /*4.301684*/,  0xc08a095b /*-4.313642*/,
  0x3ff875ff /*1.941101*/,  0xc08d640c /*-4.418463*/,  0x40b87d74 /*5.765314*/,  0xbe334ef7 /*-0.175106*/,
  0x3e733270 /*0.237497*/,  0xbf8500c1 /*-1.039086*/,  0xc010bb24 /*-2.261422*/,  0x40362061 /*2.845726*/,
  0xc07dcc4d /*-3.965595*/,  0x3fa04d5a /*1.252361*/,  0xbf93a3c9 /*-1.153436*/,  0x4031351e /*2.768867*/,
  0x40812923 /*4.036272*/,  0xbfc47686 /*-1.534867*/,  0x3ed93806 /*0.424256*/,  0x3f77f887 /*0.968636*/,
  0xbd852fa0 /*-0.065032*/,  0x401268ac /*2.287639*/,  0x3fc9a77a /*1.575423*/,  0x4022a95e /*2.541587*/,
  0x3fb99ae8 /*1.450040*/,  0xc0003c38 /*-2.003675*/,  0x408e70a8 /*4.451252*/,  0x3fba099f /*1.453419*/,
  0x406a5410 /*3.661381*/,  0x3fd2bb41 /*1.646340*/,  0xbd2c06b0 /*-0.041999*/,  0xc070420c /*-3.754031*/,
  0xbc99da40 /*-0.018781*/,  0xbec82370 /*-0.390895*/,  0x3f687f1d /*0.908190*/,  0xbebe6eb0 /*-0.371938*/,
  0x4038e297 /*2.888830*/,  0x403d872f /*2.961376*/,  0x401d8c52 /*2.461689*/,  0xbe1371a4 /*-0.143988*/,
  0x408e4211 /*4.445565*/,  0xc06e765b /*-3.725974*/,  0x4066bae0 /*3.605156*/,  0x402f4ebd /*2.739181*/,
  0xc09811d2 /*-4.752175*/,  0xc0511694 /*-3.267003*/,  0x3f978c10 /*1.183962*/,  0x40035e71 /*2.052639*/,
  0xc0086b7a /*-2.131560*/,  0x400faf7e /*2.245086*/,  0x3f7dc30b /*0.991257*/,  0x3f0e35d8 /*0.555509*/,
  0xc0900fcc /*-4.501928*/,  0xc0b99e11 /*-5.800545*/,  0xbfb962fc /*-1.448333*/,  0xbfff0c00 /*-1.992554*/,
  0x4003ad50 /*2.057453*/,  0x3e2beb38 /*0.167889*/,  0xbfd750e0 /*-1.682156*/,  0x3f01f92d /*0.507708*/,
  0xbf80b8d0 /*-1.005640*/,  0x3fe3ef5e /*1.780742*/,  0x4087f955 /*4.249186*/,  0xbe9f8dce /*-0.311629*/,
  0x3f07a168 /*0.529807*/,  0xbf270568 /*-0.652426*/,  0x3e695b10 /*0.227886*/,  0xc007af7c /*-2.120086*/,
  0xc00d3550 /*-2.206379*/,  0x40cd11a0 /*6.408401*/,  0x3f269feb /*0.650878*/,  0x4091c452 /*4.555215*/,
  0xc04f2510 /*-3.236637*/,  0xbee654bc /*-0.449865*/,  0xc0115f77 /*-2.271452*/,  0x3e3214e8 /*0.173908*/,
  0xc04eb82b /*-3.229991*/,  0x3f328184 /*0.697289*/,  0xbd8994e0 /*-0.067178*/,  0x408f6773 /*4.481378*/,
  0x404ea1c3 /*3.228623*/,  0x40141dd9 /*2.314322*/,  0x3eec9078 /*0.462040*/,  0x3f497aa9 /*0.787028*/,
  0xbf78feca /*-0.972638*/,  0xc0cc5636 /*-6.385524*/,  0x3f03094d /*0.511861*/,  0x4083077f /*4.094665*/,
  0xbff048ee /*-1.877226*/,  0x3ff2505a /*1.893077*/,  0xc07f61f9 /*-3.990355*/,  0xc05bb7de /*-3.433097*/,
  0x3fae12f3 /*1.359953*/,  0x40b01306 /*5.502322*/,  0x40a5fe26 /*5.187274*/,  0x3fd8458c /*1.689622*/,
  0x3f8a87ec /*1.082273*/,  0x40476c02 /*3.115967*/,  0x3f8a3761 /*1.079815*/,  0x409e4086 /*4.945376*/,
  0xbe86e3e1 /*-0.263457*/,  0x40323aee /*2.784847*/,  0x403173ac /*2.772685*/,  0x40a4eb42 /*5.153718*/,
  0x3dc27890 /*0.094957*/,  0x402f3156 /*2.737386*/,  0xbf37641d /*-0.716371*/,  0xc0126ae2 /*-2.287774*/,
  0x40737dbb /*3.804549*/,  0xbf90407e /*-1.126968*/,  0xc0641013 /*-3.563481*/,  0x4031ae60 /*2.776268*/,
  0x3e409cbe /*0.188098*/,  0x404623d4 /*3.095937*/,  0xc0402a1e /*-3.002571*/,  0xbf8e3e9a /*-1.111285*/ };

//Expected Ibeta, corresponding to randomly generated Id, Iq and theta
static unsigned int std_Ibeta[128] @ "RAM_code_region" = {
  0x3cf9bd40 /*0.030486*/,  0xbe390188 /*-0.180670*/,  0x4006d126 /*2.106515*/,  0x3fa71042 /*1.305184*/,
  0xc000e1e9 /*-2.013788*/,  0xc03ea466 /*-2.978784*/,  0x3f9b8587 /*1.215012*/,  0x4027f6e0 /*2.624443*/,
  0x405dd2d6 /*3.465993*/,  0x3f991668 /*1.195996*/,  0xc01d23a4 /*-2.455300*/,  0xbf2435d5 /*-0.641446*/,
  0xbfc0c903 /*-1.506134*/,  0x3fefc90e /*1.873323*/,  0x4015930e /*2.337101*/,  0x408fcd81 /*4.493836*/,
  0x40af7f36 /*5.484279*/,  0xbf5661c4 /*-0.837429*/,  0xbf4d9634 /*-0.803073*/,  0xbff423b6 /*-1.907340*/,
  0xc0a62240 /*-5.191681*/,  0xc0353a90 /*-2.831699*/,  0x3ff99f14 /*1.950167*/,  0x407152d9 /*3.770682*/,
  0x3fb93a70 /*1.447096*/,  0x409242a3 /*4.570634*/,  0xc0a7c75f /*-5.243087*/,  0xc0a6a75e /*-5.207931*/,
  0xc067acc5 /*-3.619920*/,  0xc0784c49 /*-3.879656*/,  0xbfa2e088 /*-1.272477*/,  0x403cd5a8 /*2.950541*/,
  0x40bd3fee /*5.914054*/,  0x3f21119a /*0.629175*/,  0x4099f772 /*4.811456*/,  0xc059c30c /*-3.402530*/,
  0xbf9daf5b /*-1.231914*/,  0xc099818a /*-4.797063*/,  0xc07dc4cf /*-3.965137*/,  0x40285413 /*2.630131*/,
  0x3f212504 /*0.629471*/,  0x4013f1d0 /*2.311634*/,  0x3fedf89e /*1.859150*/,  0xbfe09ea1 /*-1.754841*/,
  0x4093167e /*4.596496*/,  0xc0cfbc6a /*-6.491750*/,  0xc05e4092 /*-3.472691*/,  0x40bb8d66 /*5.861011*/,
  0xc08465e3 /*-4.137437*/,  0x3f944d64 /*1.158612*/,  0xc05815f0 /*-3.376339*/,  0xbee11814 /*-0.439637*/,
  0xc0560346 /*-3.343950*/,  0xbfb79405 /*-1.434205*/,  0xbf8511f2 /*-1.039610*/,  0xc09f9d26 /*-4.987933*/,
  0xbea6d5b4 /*-0.325849*/,  0x4036c804 /*2.855958*/,  0xc09700be /*-4.718841*/,  0x3fabccdb /*1.342189*/,
  0xc08e4c6e /*-4.446830*/,  0xc066b6c2 /*-3.604905*/,  0xc00bceb1 /*-2.184490*/,  0xc0a9aa62 /*-5.302049*/,
  0xbeb649f0 /*-0.356033*/,  0x3f222048 /*0.633305*/,  0x3ffbf0b6 /*1.968283*/,  0x408dfc50 /*4.437050*/,
  0x404389e0 /*3.055290*/,  0xc09768fc /*-4.731565*/,  0x40286956 /*2.631429*/,  0xbfe8a9fc /*-1.817688*/,
  0xbf8543e5 /*-1.041134*/,  0xc08a2e23 /*-4.318132*/,  0x40467e57 /*3.101461*/,  0xc08ad61e /*-4.338637*/,
  0x40ca8d26 /*6.329730*/,  0x4099b154 /*4.802896*/,  0xc027a92a /*-2.619700*/,  0x406c7c5d /*3.695091*/,
  0x400948b0 /*2.145061*/,  0x400240a1 /*2.035195*/,  0xc00ff05e /*-2.249046*/,  0xc0513a38 /*-3.269178*/,
  0x40a6e719 /*5.215710*/,  0x401a9353 /*2.415242*/,  0x4047ded0 /*3.122974*/,  0x3fa4c93c /*1.287391*/,
  0xc062d932 /*-3.544507*/,  0x40b0fc82 /*5.530824*/,  0xbf94be28 /*-1.162053*/,  0xbff5e7d6 /*-1.921138*/,
  0xbc49af00 /*-0.012310*/,  0xc01dffd0 /*-2.468739*/,  0x3f567158 /*0.837667*/,  0xbfcc2381 /*-1.594833*/,
  0x3f7578de /*0.958876*/,  0x3dcabf60 /*0.098998*/,  0xbea23dbd /*-0.316877*/,  0xbe42566c /*-0.189783*/,
  0xbf3f7ee2 /*-0.748030*/,  0x4060cd18 /*3.512518*/,  0x3f8f74c8 /*1.120751*/,  0xc060ccb9 /*-3.512495*/,
  0x3fbf7f81 /*1.496079*/,  0xbf340c60 /*-0.703314*/,  0xbf9cec16 /*-1.225955*/,  0xbf5ba0ec /*-0.857924*/,
  0x3ff091ac /*1.879446*/,  0xc04ce1a2 /*-3.201272*/,  0x3ff3da65 /*1.905102*/,  0xc01c3b34 /*-2.441113*/,
  0x3fbf7c8f /*1.495989*/,  0xbef1a7d2 /*-0.471983*/,  0xc03cd3a3 /*-2.950417*/,  0x3f15863c /*0.584080*/,
  0x40a38fd8 /*5.111309*/,  0xbf935ec0 /*-1.151329*/,  0xbf62255a /*-0.883382*/,  0x3c106440 /*0.008813*/,
  0xbe4b2c50 /*-0.198411*/,  0xbfc92537 /*-1.571448*/,  0x40881c16 /*4.253428*/,  0x40ce4f86 /*6.447207*/,
  0x3ea94c32 /*0.330659*/,  0x40916fbb /*4.544889*/,  0x4044192f /*3.064037*/,  0x409b58d0 /*4.854591*/ };

#endif /*__IPARK_H__*/
