#ifndef __PARK_H__
#define __PARK_H__

#include "common.h"

/**************************************************************************************************************************
	Function name	:	park_xform
	Description		:	This transformation converts vectors in balanced 2-phase orthogonal stationary system into 
						orthogonal rotating reference frame.
						Implements the following equations:
							Id =  Ialpha * cos(theta) + Ibeta * sin(theta)
							Iq = -Ialpha * sin(theta) + Ibeta * cos(theta)
	Arguments		:	Parameter	|	Description								|	Valid values
						Ialpha		|	stationary alpha-axis stator variable
						Ibeta		|	stationary beta-axis stator variable
						theta		|	rotating angle (from Ialpha to Id)
						Id			|	rotating d-axis stator variable
						Iq			|	rotating q-axis stator variable
	Return value	:	None.
**************************************************************************************************************************/
void park_xform(float Ialpha, float Ibeta, float theta, float * Id, float * Iq)
{
	float stheta, ctheta;

#if TEST_MODE==M4_CMSISLIB
	theta = theta * 57.2957795131f;						// Convert radians to degrees
	arm_sin_cos_f32(theta,&stheta,&ctheta);				// Call CMSIS sin-cos function
	arm_park_f32(Ialpha, Ibeta, Id, Iq, stheta, ctheta);// Call CMSIS Park transform function
#else // TEST_MODE==M4_CMSISLIB
	stheta = sinf(theta);								// Call sinf() from math.h or adi_math.h
	ctheta = cosf(theta);								// Call cosf() from math.h or adi_math.h
	*Id =  Ialpha * ctheta + Ibeta * stheta;
	*Iq = -Ialpha * stheta + Ibeta * ctheta;
#endif // TEST_MODE==M4_CMSISLIB

	return;
}

#if TEST_MODE==MATH_M4_CODEINTERLEAVE

/**************************************************************************************************************************
	Function name	:	park_xform_interl
	Description		:	Implements Park Transform with Cortex-M4 and Math Unit interleaved
	Arguments		:	Parameter	|	Description										|	Valid values
						p_Ialpha	|	Pointer to stationary alpha-axis stator variable
						p_Ibeta		|	Pointer to stationary beta-axis stator variable
						p_theta		|	Pointer to rotating angle (from Ialpha to Id)
						p_Id		|	Pointer to rotating d-axis stator variable
						p_Iq		|	Pointer to rotating q-axis stator variable
						N			|	Number of Samples
	Return value	:	None.
**************************************************************************************************************************/
#pragma inline=forced
void park_xform_interl(float * p_Ialpha, float * p_Ibeta, float * p_theta, float * p_Id, float * p_Iq, unsigned int N)
{
	// Using local variables for intermediate results ensures core register usage (with compiler optimizations)
	float theta,stheta,ctheta;
	float Id_temp,Iq_temp,Ialpha_temp,Ibeta_temp;
	unsigned int idx;

	theta = p_theta[0];								// Read theta from memory
	cosf_write(theta);								// Start cosf(theta[0]) computation on Math Unit
	for( idx = 0 ; idx < (N-1) ; idx++ )
	{
		Ialpha_temp = p_Ialpha[idx];				// Read Ialpha from memory
		Ibeta_temp = p_Ibeta[idx];					// Read Ibeta from memory
		ctheta = cosf_read();						// Read cosf(theta[idx]) result from Math Unit
		sinf_write(theta);							// Start sinf(theta[idx]) computation on Math Unit
		theta = p_theta[idx+1];						// Read theta from memory
		Id_temp = Ialpha_temp * ctheta;				// Calculate Ialpha*cos(theta) on M4 core
		Iq_temp = Ibeta_temp * ctheta;				// Calculate Ibeta*cos(theta) on M4 core
		stheta = sinf_read();						// Read sinf(theta[idx]) result from Math Unit
		cosf_write(theta);							// Start cosf(theta[idx+1]) computation on Math Unit
		p_Id[idx] = Id_temp + Ibeta_temp * stheta;	// Calculate final Id on M4 core
		p_Iq[idx] = Iq_temp - Ialpha_temp * stheta;	// Calculate final Iq on M4 core
	}
	Ialpha_temp = p_Ialpha[N-1];					// Read Ialpha from memory
	Ibeta_temp = p_Ibeta[N-1];						// Read Ibeta from memory
	ctheta = cosf_read();							// Read cosf(theta[N-1]) result from Math Unit
	sinf_write(theta);								// Start sinf(theta[N-1]) computation on Math Unit
	Id_temp = Ialpha_temp * ctheta;					// Calculate Ialpha*cos(theta) on M4 core
	Iq_temp = Ibeta_temp * ctheta;					// Calculate Ibeta*cos(theta) on M4 core
	stheta = sinf_read();							// Read sinf(theta[N-1]) result from Math
	p_Id[N-1] = Id_temp + Ibeta_temp * stheta;		// Calculate final Id on M4 core
	p_Iq[N-1] = Iq_temp - Ialpha_temp * stheta;		// Calculate final Iq on M4 core

	return;
}

#endif //TEST_MODE==MATH_M4_CODEINTERLEAVE

#define NUM_SAMPLES    (128)	// Number of computations

//Randomly generated test vector for Ialpha
static unsigned int std_Ialpha[128] @ "RAM_code_region" = {
  0x3ff33388 /*1.900010*/,  0x3d5df040 /*0.054184*/,  0x3f6a3742 /*0.914906*/,  0x3f0c3fd4 /*0.547849*/,
  0xbf9b9c72 /*-1.215712*/,  0xc01b0d2b /*-2.422679*/,  0xc03b4682 /*-2.926178*/,  0x3fa19d84 /*1.262619*/,
  0xbfcca32b /*-1.598729*/,  0x405c10b0 /*3.438519*/,  0xc089fdb4 /*-4.312220*/,  0xbf66a36b /*-0.900931*/,
  0x40733239 /*3.799940*/,  0xbfe710b2 /*-1.805197*/,  0x4099c825 /*4.805682*/,  0xc084cc68 /*-4.149952*/,
  0x408270f7 /*4.076290*/,  0xc07e64da /*-3.974905*/,  0x4087086b /*4.219778*/,  0x3d9aa600 /*0.075512*/,
  0x406e43de /*3.722892*/,  0xbfd56d74 /*-1.667403*/,  0x3ff648bb /*1.924095*/,  0x3f11c846 /*0.569462*/,
  0xbfb0bfa0 /*-1.380848*/,  0xc095c311 /*-4.680062*/,  0x40657275 /*3.585111*/,  0xc0805331 /*-4.010155*/,
  0x407152be /*3.770675*/,  0xbf01e5ac /*-0.507411*/,  0xbf2d9643 /*-0.678074*/,  0x3f8805e0 /*1.062679*/,
  0x4088e876 /*4.278377*/,  0x3fd24920 /*1.642857*/,  0xbf85eeae /*-1.046346*/,  0xbf1d84fb /*-0.615310*/,
  0x3fc2b857 /*1.521251*/,  0x40893c81 /*4.288636*/,  0x408fb9d3 /*4.491434*/,  0xbff69c3a /*-1.926643*/,
  0x3f76ff0e /*0.964829*/,  0x40352b33 /*2.830762*/,  0xbfcf5236 /*-1.619696*/,  0x40435c9e /*3.052528*/,
  0x408d80c0 /*4.421967*/,  0xc08aba80 /*-4.335266*/,  0x4064891c /*3.570868*/,  0x4098b5ba /*4.772183*/,
  0x40795fa4 /*3.896462*/,  0x3ee7cfac /*0.452756*/,  0x406932aa /*3.643717*/,  0xbed83434 /*-0.422273*/,
  0x404023f3 /*3.002194*/,  0x406f2bec /*3.737056*/,  0x404df6ba /*3.218184*/,  0xc049229e /*-3.142738*/,
  0xc084652b /*-4.137350*/,  0x3fb0d6e6 /*1.381558*/,  0xc02a59a1 /*-2.661721*/,  0xbebedd5e /*-0.372783*/,
  0xc09da02a /*-4.925801*/,  0x3facd041 /*1.350105*/,  0xbf4998e8 /*-0.787489*/,  0x40912bb0 /*4.536583*/,
  0xc03985dd /*-2.898795*/,  0x4096a3e3 /*4.707506*/,  0xc018cc62 /*-2.387475*/,  0x4064856a /*3.570643*/,
  0x3f503630 /*0.813327*/,  0x4004af08 /*2.073183*/,  0xc008f9d2 /*-2.140248*/,  0xbfe8b2fc /*-1.817962*/,
  0x3fb84214 /*1.439517*/,  0x406573a4 /*3.585183*/,  0x3fd82de0 /*1.688900*/,  0xbf11896c /*-0.568503*/,
  0xc08e1d16 /*-4.441051*/,  0x403191d8 /*2.774527*/,  0x3f7269bc /*0.946926*/,  0xc07eaaf1 /*-3.979183*/,
  0xc0004912 /*-2.004460*/,  0x40903aed /*4.507193*/,  0x3fd41f2a /*1.657201*/,  0x408f4592 /*4.477242*/,
  0x4072d74c /*3.794391*/,  0x40008df6 /*2.008665*/,  0xbf9ebc7e /*-1.240127*/,  0x3f9141d2 /*1.134821*/,
  0x406868f4 /*3.631406*/,  0xc068d9b1 /*-3.638287*/,  0xbf1a67e9 /*-0.603148*/,  0xc0104623 /*-2.254281*/,
  0xc0487118 /*-3.131903*/,  0x3d7c7e20 /*0.061644*/,  0x3f348192 /*0.705102*/,  0x3fdd384e /*1.728281*/,
  0x3f9e3e00 /*1.236267*/,  0xc08c6276 /*-4.387019*/,  0x3f012b12 /*0.504563*/,  0x3f23b8e4 /*0.639540*/,
  0x3ebb4bbc /*0.365812*/,  0xc07d4a5c /*-3.957664*/,  0x3f7ecde2 /*0.995329*/,  0xc00f271a /*-2.236762*/,
  0xbfc9c870 /*-1.576429*/,  0x4019c8fc /*2.402892*/,  0x40946dec /*4.638418*/,  0xbff150a2 /*-1.885273*/,
  0xbf9e398c /*-1.236131*/,  0x3f18c2ae /*0.596721*/,  0xbe8c1752 /*-0.273615*/,  0x4096d69d /*4.713698*/,
  0x3fabafe0 /*1.341305*/,  0xbfba4e97 /*-1.455523*/,  0xbfa28f16 /*-1.269992*/,  0xbfccd308 /*-1.600190*/,
  0xc09f24b7 /*-4.973232*/,  0x4015d26c /*2.340968*/,  0x3f67924e /*0.904576*/,  0x3f7f69f0 /*0.997710*/,
  0x40715900 /*3.771057*/,  0xbff71ac2 /*-1.930504*/,  0xc09bc43f /*-4.867706*/,  0x409fad9f /*4.989944*/,
  0x3eb11c14 /*0.345917*/,  0x4053935c /*3.305869*/,  0x408930c6 /*4.287204*/,  0xc09f0d32 /*-4.970361*/ };

//Randomly generated test vector for Ibeta
static unsigned int std_Ibeta[128] @ "RAM_code_region" = {
  0xbefb674c /*-0.491022*/,  0x4010e54d /*2.263995*/,  0xbffa3546 /*-1.954751*/,  0x408bb2da /*4.365582*/,
  0xc0780d3b /*-3.875808*/,  0xbfdf2e8d /*-1.743608*/,  0xc0722b23 /*-3.783883*/,  0x4085648d /*4.168524*/,
  0x4073cb2e /*3.809276*/,  0x407ed7f1 /*3.981930*/,  0xc01e3114 /*-2.471745*/,  0x3e935d14 /*0.287820*/,
  0x4092dcd7 /*4.589458*/,  0xc0247757 /*-2.569784*/,  0xbf6f0c3b /*-0.933780*/,  0x4094a752 /*4.645425*/,
  0x4084d344 /*4.150789*/,  0x40069dd8 /*2.103384*/,  0xc0804f02 /*-4.009645*/,  0x3ff4f9c0 /*1.913872*/,
  0x40681540 /*3.626297*/,  0xc020de2e /*-2.513561*/,  0xc0122745 /*-2.283647*/,  0x409610d2 /*4.689553*/,
  0xc07f4e2b /*-3.989146*/,  0xbf3ee8a8 /*-0.745738*/,  0x407fbd1f /*3.995918*/,  0x408a687b /*4.325254*/,
  0xc07954ea /*-3.895808*/,  0x40848540 /*4.141266*/,  0xbf94234d /*-1.157327*/,  0x403ac054 /*2.917989*/,
  0xc082acd2 /*-4.083596*/,  0xbfdb1b72 /*-1.711775*/,  0xc09e8320 /*-4.953506*/,  0x40867836 /*4.202174*/,
  0x3f9247bc /*1.142814*/,  0xc03c0e94 /*-2.938390*/,  0xc07ada22 /*-3.919564*/,  0xc0139707 /*-2.306093*/,
  0xc0659ba2 /*-3.587624*/,  0x3e4f0648 /*0.202172*/,  0x3f69e602 /*0.913666*/,  0xc0335cfe /*-2.802551*/,
  0x3fa09ace /*1.254724*/,  0x409b211b /*4.847791*/,  0x3ebaecd0 /*0.365088*/,  0xc05b1055 /*-3.422872*/,
  0x404d366f /*3.206447*/,  0x404971a4 /*3.147561*/,  0xc002e4ce /*-2.045215*/,  0x3e417988 /*0.188940*/,
  0xc095dc5a /*-4.683148*/,  0xbfb3d988 /*-1.405076*/,  0xbff6eb16 /*-1.929049*/,  0xc097cf11 /*-4.744027*/,
  0x4017117f /*2.360443*/,  0x4083a203 /*4.113527*/,  0x40825120 /*4.072403*/,  0xc01b2302 /*-2.424012*/,
  0xbe6eab38 /*-0.233075*/,  0xc080d95b /*-4.026533*/,  0xc011050a /*-2.265933*/,  0x40333265 /*2.799951*/,
  0x405d9ecc /*3.462817*/,  0xc05ca77b /*-3.447722*/,  0x3f057532 /*0.521320*/,  0x40536058 /*3.302755*/,
  0xc065ec55 /*-3.592550*/,  0x40883544 /*4.256502*/,  0xc011919c /*-2.274512*/,  0x3f01b8ac /*0.506724*/,
  0xbe1b8444 /*-0.151872*/,  0x403f9cf6 /*2.993955*/,  0xc09f6e23 /*-4.982194*/,  0x408a0008 /*4.312504*/,
  0xc0915231 /*-4.541283*/,  0xc07e5bca /*-3.974352*/,  0x401d00e6 /*2.453180*/,  0xbfc2bc28 /*-1.521367*/,
  0x40156e3a /*2.334853*/,  0x409fa9c2 /*4.989472*/,  0xbfd3b477 /*-1.653945*/,  0xc05802e0 /*-3.375175*/,
  0x409a679d /*4.825148*/,  0x3fb510fd /*1.414581*/,  0xc06a0e4c /*-3.657123*/,  0x3f21de48 /*0.632298*/,
  0xc0487241 /*-3.131974*/,  0xc0872804 /*-4.223635*/,  0x3f7edb7a /*0.995536*/,  0x408a593f /*4.323394*/,
  0xbf48d10b /*-0.784440*/,  0xc0588890 /*-3.383335*/,  0xbf2582d2 /*-0.646527*/,  0x3ed6c450 /*0.419466*/,
  0x3f14a2fa /*0.580612*/,  0x409482fb /*4.640989*/,  0xbea82064 /*-0.328372*/,  0xc0819048 /*-4.048862*/,
  0xbffe62b0 /*-1.987387*/,  0x3f022346 /*0.508351*/,  0xc080c04a /*-4.023473*/,  0xc08bed52 /*-4.372720*/,
  0xbfa20a32 /*-1.265936*/,  0xc09ffcfb /*-4.999631*/,  0xc028104e /*-2.625995*/,  0x3e43e8f8 /*0.191318*/,
  0xbfe4195e /*-1.782024*/,  0x408dacbf /*4.427337*/,  0xc00b0d3c /*-2.172683*/,  0xc0373b96 /*-2.863012*/,
  0x3f3683b6 /*0.712947*/,  0xc01aec15 /*-2.420659*/,  0x40760b9e /*3.844459*/,  0xc09de0d5 /*-4.933695*/,
  0xbf9787e0 /*-1.183834*/,  0xbfe9e224 /*-1.827214*/,  0x3f307d90 /*0.689416*/,  0xc003c2fe /*-2.058776*/,
  0xbf0a97a1 /*-0.541376*/,  0x3de67120 /*0.112520*/,  0xc02a7aa7 /*-2.663736*/,  0x409dfc6e /*4.937064*/,
  0x3e221868 /*0.158296*/,  0xc08ca027 /*-4.394550*/,  0x3e1d6ed0 /*0.153743*/,  0x3e9fe598 /*0.312299*/ };

//Randomly generated test vector for theta
static unsigned int std_theta[128] @ "RAM_code_region" = {
  0xc039dee6 /*-2.904230*/,  0xbfd038bb /*-1.626731*/,  0x403b16b1 /*2.923260*/,  0xbf92881f /*-1.144779*/,
  0xbf3f85d5 /*-0.748136*/,  0x3f8165c4 /*1.010918*/,  0x401f18b8 /*2.485884*/,  0xbf21472e /*-0.629992*/,
  0xbf7905d3 /*-0.972745*/,  0xbf211109 /*-0.629166*/,  0xbb79a890 /*-0.003809*/,  0x3f86fb79 /*1.054549*/,
  0xbf914064 /*-1.134778*/,  0xbfcc7ce6 /*-1.597562*/,  0x3f3089a1 /*0.689600*/,  0x3d12b559 /*0.035817*/,
  0x3edf50ca /*0.436163*/,  0x3f2c8c3e /*0.674015*/,  0x3f1f1865 /*0.621466*/,  0x4045ba00 /*3.089478*/,
  0xc0130795 /*-2.297338*/,  0x3e6fa2c4 /*0.234019*/,  0xc03ee294 /*-2.982579*/,  0xbf0691b3 /*-0.525661*/,
  0xbfcb31a2 /*-1.587452*/,  0xbfff8517 /*-1.996249*/,  0xc0281eaf /*-2.626873*/,  0x40387d19 /*2.882635*/,
  0x3d90aff8 /*0.070648*/,  0x4029261a /*2.642951*/,  0x3f5a0fcc /*0.851804*/,  0x3d03440c /*0.032047*/,
  0x40160279 /*2.343901*/,  0x3f8983d7 /*1.074336*/,  0x4042222e /*3.033336*/,  0xc0294ead /*-2.645427*/,
  0xbfac9cd2 /*-1.348536*/,  0xbfaed14f /*-1.365763*/,  0xbc26fd39 /*-0.010192*/,  0xc03cd409 /*-2.950442*/,
  0x3fbd3a25 /*1.478337*/,  0x3f61711f /*0.880632*/,  0xbf846e0a /*-1.034608*/,  0xbffb1553 /*-1.961588*/,
  0x3fa63204 /*1.298401*/,  0x40168402 /*2.351807*/,  0xbfb55c9b /*-1.416889*/,  0x40106898 /*2.256384*/,
  0xbfd32d73 /*-1.649825*/,  0xbf870a3d /*-1.055000*/,  0xbedbd105 /*-0.429329*/,  0x3fd666b8 /*1.675010*/,
  0x3eb62e52 /*0.355822*/,  0xc01a877b /*-2.414519*/,  0x3e84bb84 /*0.259243*/,  0x3f8b2c2a /*1.087285*/,
  0x3f16408f /*0.586923*/,  0x3f9695e8 /*1.176450*/,  0x4033bec1 /*2.808518*/,  0x40135bfd /*2.302490*/,
  0x3f89cbab /*1.076528*/,  0x3e6f1692 /*0.233485*/,  0x3f42ad9d /*0.760462*/,  0xc0013d5f /*-2.019371*/,
  0x3f73e741 /*0.952747*/,  0xc02790b9 /*-2.618208*/,  0xbf38b052 /*-0.721440*/,  0x3f9f8b2c /*1.246435*/,
  0x4014e214 /*2.326299*/,  0xc029c8cb /*-2.652880*/,  0xbfe8ae18 /*-1.817813*/,  0x40075c34 /*2.115003*/,
  0xc00ef59f /*-2.233742*/,  0xbff00e28 /*-1.875432*/,  0x3fefeed0 /*1.874475*/,  0x403c159a /*2.938818*/,
  0xc01cdae2 /*-2.450860*/,  0x402ab29c /*2.667151*/,  0xc02beead /*-2.686443*/,  0xbfb52150 /*-1.415079*/,
  0x3db87d87 /*0.090083*/,  0xbf075452 /*-0.528630*/,  0xbf013275 /*-0.504676*/,  0x3cc0428c /*0.023469*/,
  0x3f9c632b /*1.221776*/,  0x3f9218c9 /*1.141381*/,  0xc00be48b /*-2.185824*/,  0x3f6d9d95 /*0.928186*/,
  0xbfcc8ef8 /*-1.598113*/,  0xc023943c /*-2.555923*/,  0x40228131 /*2.539135*/,  0xc01d360a /*-2.456423*/,
  0x40391c73 /*2.892361*/,  0x3f3c22e6 /*0.734908*/,  0x3fe787c1 /*1.808830*/,  0xbfacdc6d /*-1.350477*/,
  0x3ff64db1 /*1.924246*/,  0x3f4c4b07 /*0.798020*/,  0x3cb947c4 /*0.022617*/,  0x3faf14b6 /*1.367820*/,
  0xbfafd33a /*-1.373634*/,  0xbff7fbbc /*-1.937370*/,  0xc005935b /*-2.087119*/,  0xbe9a2f2b /*-0.301141*/,
  0xc03f0cdd /*-2.985160*/,  0x3f7ee2a3 /*0.995646*/,  0x3e90ee8e /*0.283070*/,  0x40317707 /*2.772890*/,
  0xc043afb9 /*-3.057600*/,  0xc00f1618 /*-2.235723*/,  0x403013ee /*2.751216*/,  0x3db2cba2 /*0.087302*/,
  0x3fa0d714 /*1.256564*/,  0x3ff8de1a /*1.944278*/,  0xc02d33f8 /*-2.706297*/,  0x3fffa6e3 /*1.997280*/,
  0xbfe95a29 /*-1.823064*/,  0x3e877d3f /*0.264627*/,  0xc039d150 /*-2.903400*/,  0xc001a887 /*-2.025911*/,
  0x3db94f08 /*0.090483*/,  0x3f80e124 /*1.006871*/,  0xbfafe3f8 /*-1.374145*/,  0x3ec4a9be /*0.384108*/,
  0x3f1fda44 /*0.624424*/,  0x3ff3070c /*1.898653*/,  0x4013da9a /*2.310217*/,  0xbfa439a9 /*-1.283010*/ };

//Expected Id, corresponding to randomly generated Ialpha, Ibeta and theta
static unsigned int std_Id[128] @ "RAM_code_region" = {
  0xbfdd9a7f /*-1.731277*/,  0xc010dceb /*-2.263484*/,  0xbfa885fd /*-1.316589*/,  0xc06fef5d /*-3.748985*/,
  0x3fdf6df8 /*1.745543*/,  0xc030e5fc /*-2.764037*/,  0x3c483d00 /*0.012222*/,  0xbfb7c1ca /*-1.435601*/,
  0xc0818b4c /*-4.048254*/,  0x3edfaba0 /*0.436856*/,  0xc089b04f /*-4.302772*/,  0xbe4712a6 /*-0.194407*/,
  0xc02388cf /*-2.555225*/,  0x40277fc9 /*2.617174*/,  0x40474364 /*3.113488*/,  0xc07ec7b2 /*-3.980938*/,
  0x40ae57e1 /*5.448227*/,  0xbfe57dc6 /*-1.792901*/,  0x3f8c5252 /*1.096262*/,  0x3cc6f5b8 /*0.024287*/,
  0xc0a5e06c /*-5.183645*/,  0xc00d1bc8 /*-2.204821*/,  0xbfc4e454 /*-1.538218*/,  0xbfee26fe /*-1.860565*/,
  0x40805ef4 /*4.011591*/,  0x4027188d /*2.610873*/,  0xc0a2cecf /*-5.087745*/,  0x409f7d25 /*4.984026*/,
  0x405f1efd /*3.486266*/,  0x401b457f /*2.426117*/,  0xbfa8a240 /*-1.317451*/,  0x3f93ebbb /*1.155631*/,
  0xc0bd2430 /*-5.910667*/,  0xbf38fc51 /*-0.722600*/,  0x3f0148e8 /*0.505019*/,  0xbfbacc5f /*-1.459362*/,
  0xbf478484 /*-0.779366*/,  0x40700028 /*3.750010*/,  0x4090ff2c /*4.531149*/,  0x4015198a /*2.329684*/,
  0xc05eed12 /*-3.483220*/,  0x3ffaa48d /*1.958147*/,  0xbfce7312 /*-1.612887*/,  0x3fb6d8b8 /*1.428489*/,
  0x40197b2c /*2.398143*/,  0x40cfd677 /*6.494930*/,  0x3e3f1fc4 /*0.186645*/,  0xc0b577be /*-5.670867*/,
  0xc0604259 /*-3.504050*/,  0xc020f1b3 /*-2.514752*/,  0x40854291 /*4.164376*/,  0x3e6d6800 /*0.231842*/,
  0x3f976313 /*1.182711*/,  0xbfedd662 /*-1.858105*/,  0x40276ec6 /*2.616136*/,  0xc0b528e0 /*-5.661240*/,
  0xc008d0c9 /*-2.137743*/,  0x408a83f1 /*4.328606*/,  0x407633c8 /*3.846910*/,  0xbfc6fa00 /*-1.554504*/,
  0xc022aece /*-2.541919*/,  0x3ec382ce /*0.381857*/,  0xc008788c /*-2.132358*/,  0xc08fb123 /*-4.490373*/,
  0x3f923ea5 /*1.142537*/,  0xc016a99e /*-2.354103*/,  0xc008c3fc /*-2.136962*/,  0x4088979f /*4.268508*/,
  0xc04b0ec2 /*-3.172776*/,  0xc0750c48 /*-3.828875*/,  0x402ea47a /*2.728789*/,  0x3faff7e2 /*1.374752*/,
  0xbf4427f2 /*-0.766235*/,  0xc07b9d15 /*-3.931463*/,  0xc0a84bdb /*-5.259260*/,  0x3fb67188 /*1.425340*/,
  0x40ca1f63 /*6.316331*/,  0xc0891444 /*-4.283724*/,  0xbff6e756 /*-1.928935*/,  0x3f62c5f5 /*0.885833*/,
  0xbfe4a502 /*-1.786286*/,  0x3fb010ae /*1.375509*/,  0x40100545 /*2.250322*/,  0x408cb29e /*4.396804*/,
  0x40ba9e52 /*5.831826*/,  0x4007d5fc /*2.122436*/,  0x406cf5f5 /*3.702512*/,  0x3f97d75e /*1.186260*/,
  0x4042060d /*3.031619*/,  0x40abbb10 /*5.366585*/,  0x3f87d226 /*1.061101*/,  0xbf7d8746 /*-0.990345*/,
  0x4035dd83 /*2.841645*/,  0xc00e4345 /*-2.222856*/,  0xbf4b67fc /*-0.794555*/,  0xbd018a70 /*-0.031626*/,
  0x3def36f4 /*0.116804*/,  0x3e853138 /*0.260141*/,  0x3efe77db /*0.497008*/,  0xc0758e78 /*-3.836821*/,
  0x4001508f /*2.020542*/,  0x3f71a505 /*0.943924*/,  0x40407c73 /*3.007596*/,  0xbf56d000 /*-0.839111*/,
  0x3fe09069 /*1.754407*/,  0xc038d7a7 /*-2.888162*/,  0x406e1a81 /*3.720368*/,  0x3fe9ec66 /*1.827527*/,
  0x3fb0cd96 /*1.381274*/,  0xc0768c74 /*-3.852323*/,  0xbf12e196 /*-0.573755*/,  0x408e4694 /*4.446115*/,
  0x3f8bdadc /*1.092617*/,  0xbfdc823c /*-1.722724*/,  0xbef06b18 /*-0.469567*/,  0xc0751b97 /*-3.829809*/,
  0x4018cfd6 /*2.387685*/,  0x3fe40a8c /*1.781572*/,  0xbf85567a /*-1.041702*/,  0x3fb49060 /*1.410656*/,
  0x406d3ac5 /*3.706712*/,  0xbf6fd048 /*-0.936772*/,  0x3fd4a5d6 /*1.661311*/,  0x40cf3ed2 /*6.476418*/,
  0x3ebf126d /*0.373187*/,  0xc0a73348 /*-5.225010*/,  0xc0319fdc /*-2.775382*/,  0xbfdae7b0 /*-1.710196*/ };

//Expected Iq, corresponding to randomly generated Ialpha, Ibeta and theta
static unsigned int std_Iq[128] @ "RAM_code_region" = {
  0x3f6c8cd7 /*0.924024*/,  0xbd946bac /*-0.072471*/,  0x3fdae6fe /*1.710174*/,  0x4013637b /*2.302947*/,
  0xc06abd97 /*-3.667822*/,  0x3f903a6c /*1.126783*/,  0x409910f3 /*4.783319*/,  0x408396ce /*4.112159*/,
  0x3f52d11a /*0.823503*/,  0x40a7c619 /*5.242932*/,  0xc01f3dee /*-2.488155*/,  0x3f6cf3ad /*0.925593*/,
  0x40ac3f1b /*5.382703*/,  0xbfde2df6 /*-1.735778*/,  0xc071c984 /*-3.777925*/,  0x40995051 /*4.791054*/,
  0x400290fd /*2.040099*/,  0x4083fa06 /*4.124270*/,  0xc0b6f028 /*-5.716816*/,  0xbff52580 /*-1.915207*/,
  0x3ebf6b80 /*0.373867*/,  0xc003bcba /*-2.058394*/,  0x4023cef0 /*2.559505*/,  0x408af31c /*4.342176*/,
  0xbfa83842 /*-1.314217*/,  0xc07d1f96 /*-3.955053*/,  0xbfdb4bd3 /*-1.713251*/,  0xc049dd8f /*-3.154148*/,
  0xc084df4f /*-4.152259*/,  0xc0593cc7 /*-3.394335*/,  0xbe810860 /*-0.252017*/,  0x403879e6 /*2.882440*/,
  0xbe577520 /*-0.210408*/,  0xc010a1aa /*-2.259867*/,  0x40a133b4 /*5.037561*/,  0xc07f418a /*-3.988375*/,
  0x3fde2cf3 /*1.735747*/,  0x40666f68 /*3.600550*/,  0xc077e8cb /*-3.873584*/,  0x3ff2f346 /*1.898049*/,
  0xbfa55e77 /*-1.291945*/,  0xc003780e /*-2.054203*/,  0xbf6cf657 /*-0.925634*/,  0x4078f4ca /*3.889941*/,
  0xc07af780 /*-3.921356*/,  0xbeaaf740 /*-0.333918*/,  0x40656a8a /*3.584628*/,  0xbfc36d82 /*-1.526779*/,
  0x40686503 /*3.631165*/,  0x3ff920ee /*1.946317*/,  0xbeaf8c08 /*-0.342865*/,  0x3eccf7c6 /*0.400328*/,
  0xc0adf0cf /*-5.435646*/,  0x406228b0 /*3.533733*/,  0xc02c21de /*-2.689567*/,  0x3f13b800 /*0.577026*/,
  0x408836cd /*4.256690*/,  0x3e9c1e14 /*0.304917*/,  0xc03e9d1a /*-2.978339*/,  0x3ff2ce5d /*1.896923*/,
  0x408738e2 /*4.225694*/,  0xc087594a /*-4.229650*/,  0xbf8ca9a2 /*-1.098927*/,  0x4037e704 /*2.873475*/,
  0x408bcf61 /*4.369065*/,  0x40aad99c /*5.339064*/,  0xbf97bb98 /*-1.185412*/,  0xc0153d03 /*-2.331849*/,
  0x3fef83a4 /*1.871205*/,  0xc0323ba8 /*-2.784891*/,  0xbfc27317 /*-1.519137*/,  0x3fa5808e /*1.292986*/,
  0x3f9d316b /*1.228071*/,  0x402169d4 /*2.522084*/,  0xbdf967c0 /*-0.121780*/,  0xc0838252 /*-4.109658*/,
  0x3f2bc18c /*0.670922*/,  0x4011249a /*2.267859*/,  0xbfe4c1ed /*-1.787168*/,  0xc08557ef /*-4.166984*/,
  0x40205d8c /*2.505710*/,  0x40d29c8e /*6.581611*/,  0xbf257df0 /*-0.646453*/,  0xc05ead14 /*-3.479314*/,
  0xbff5301b /*-1.915531*/,  0xbf9e618c /*-1.237352*/,  0x3f8c7150 /*1.097208*/,  0xbf078f97 /*-0.529535*/,
  0x406dcc52 /*3.715596*/,  0x3fc11b18 /*1.508639*/,  0xbef4fba9 /*-0.478483*/,  0xc098c608 /*-4.774174*/,
  0x3fc42ffd /*1.532714*/,  0xc0234a38 /*-2.551405*/,  0xbf0863e4 /*-0.532774*/,  0x3fe39b3d /*1.778175*/,
  0xbfae2f41 /*-1.360817*/,  0x40cc3114 /*6.380991*/,  0xbeaded07 /*-0.339699*/,  0xbfb8a742 /*-1.442604*/,
  0xbcfa8250 /*-0.030580*/,  0xc0781f80 /*-3.876923*/,  0x403685ab /*2.851908*/,  0xc09adc44 /*-4.839388*/,
  0x3f809fd7 /*1.004878*/,  0xc0978c78 /*-4.735897*/,  0xc0744a0d /*-3.817020*/,  0x3f0041b0 /*0.501002*/,
  0x3fd6055a /*1.672038*/,  0xc010c5e6 /*-2.262079*/,  0x40074106 /*2.113344*/,  0xc050d6ae /*-3.263103*/,
  0xbf8712e1 /*-1.055264*/,  0x400f41ad /*2.238384*/,  0xc080afea /*-4.021474*/,  0x405fdbc3 /*3.497788*/,
  0xc090a69c /*-4.520338*/,  0xc0180e8c /*-2.375888*/,  0xbee9bcf1 /*-0.456520*/,  0x3fe68b20 /*1.801121*/,
  0xbf6141e6 /*-0.879912*/,  0x3fd88ac1 /*1.691734*/,  0xc0a96b48 /*-5.294346*/,  0x402d4675 /*2.707425*/,
  0xbd9728ac /*-0.073808*/,  0xbfdb7a71 /*-1.714674*/,  0xc0515bfd /*-3.271240*/,  0xc095ac8a /*-4.677312*/ };

#endif /*__PARK_H__*/
